==> mmisp_lib-0.1.1.tar.gz: mmisp_lib-0.1.1/src/mmisp/api_schemas/warninglists/create_warninglist_body.py <==
from enum import Enum

from pydantic import BaseModel, Field


class WarninglistListType(str, Enum):
    CIDR = "cidr"
    HOSTNAME = "hostname"
    STRING = "string"
    SUBSTRING = "substring"
    REGEX = "regex"


class WarninglistCategory(str, Enum):
    FALSE_POSITIVE = "False positive"
    KNOWN_IDENTIFIER = "Known identifier"


class ValidAttribute(str, Enum):
    MD5 = "md5"
    SHA12SHA256 = "sha12sha256"
    FILENAME = "filename"
    PDB = "pdb"
    FILENAME_MD5 = "filename|md5"
    FILENAME_SHA1 = "filename|sha1"
    FILENAME_SHA256 = "filename|sha256"
    IP_SRC = "ip-src"
    IP_DST = "ip-dst"
    HOSTNAME = "hostname"
    DOMAIN = "domain"
    DOMAIN_IP = "domain|ip"
    EMAIL = "email"
    EMAIL_SRC = "email-src"
    EPPN = "eppn"
    EMAIL_DST = "email-dst"
    EMAIL_SUBJECT = "email-subject"
    EMAIL_ATTACHMENT = "email-attachment"
    EMAIL_BODY = "email-body"
    FLOAT = "float"
    GIT_COMMIT_ID = "git-commit-id"
    URL = "url"
    HTTP_METHOD = "http-method"
    USER_AGENT = "user-agent"
    JA3_FINGERPRINT_MD5 = "ja3-fingerprint-md5"
    JARM_FINGERPRINT = "jarm-fingerprint"
    FAVICON_MMH3 = "favicon-mmh3"
    HASSH_MD5 = "hassh-md5"
    HASSHSERVER_MD5 = "hasshserver-md5"
    REGKEY = "regkey"
    REGKEY_VALUE = "regkey|value"
    AS = "AS"
    SNORT = "snort"
    BRO = "bro"
    ZEEK = "zeek"
    COMMUNITY_ID = "community-id"
    PATTERN_IN_FILE = "pattern-in-file"
    PATTERN_IN_TRAFFIC = "pattern-in-traffic"
    PATTERN_IN_MEMORY = "pattern-in-memory"
    FILENAME_PATTERN = "filename-pattern"
    PGP_PUBLIC_KEY = "pgp-public-key"
    PGP_PRIVATE_KEY = "pgp-private-key"
    SSH_FINGERPRINT = "ssh-fingerprint"
    YARA = "yara"
    STIX2_PATTERN = "stix2-pattern"
    SIGMA = "sigma"
    GENE = "gene"
    KUSTO_QUERY = "kusto-query"
    MIME_TYPE = "mime-type"
    IDENTITY_CARD_NUMBER = "identity-card-number"
    COOKIE = "cookie"
    VULNERABILITY = "vulnerability"
    CPE = "cpe"
    WEAKNESS = "weakness"
    ATTACHMENT = "attachment"
    MALWARE_SAMPLE = "malware-sample"
    LINK = "link"
    COMMENT = "comment"
    TEXT = "text"
    HEX = "hex"
    OTHER = "other"
    NAMED_PIPE = "named pipe"
    MUTEX = "mutex"
    PROCESS_STATE = "process-state"
    TARGET_USER = "target-user"
    TARGET_EMAIL = "target-email"
    TARGET_MACHINE = "target-machine"
    TARGET_ORG = "target-org"
    TARGET_LOCATION = "target-location"
    TARGET_EXTERNAL = "target-external"
    BTC = "btc"
    DASH = "dash"
    XMR = "xmr"
    IBAN = "iban"
    BIC = "bic"
    BANK_ACCOUNT_NR = "bank-account-nr"
    ABA_RTN = "aba-rtn"
    BIN = "bin"
    CC_NUMBER = "cc-number"
    PRTN = "prtn"
    PHONE_NUMBER = "phone-number"
    THREAT_ACTOR = "threat-actor"
    CAMPAIGN_NAME = "campaign-name"
    CAMPAIGN_ID = "campaign-id"
    MALWARE_TYPE = "malware-type"
    URI = "uri"
    AUTHENTIHASH = "authentihash"
    VHASH = "vhash"
    SSDEEP = "ssdeep"
    IMPHASH = "imphash"
    TELFHASH = "telfhash"
    PEHASH = "pehash"
    IMPFUZZY = "impfuzzy"
    SHA224 = "sha224"
    SHA384 = "sha384"
    SHA512 = "sha512"
    SHA512_224 = "sha512/224"
    SHA512_256 = "sha512/256"
    SHA3_224 = "sha3-224"
    SHA3_256 = "sha3-256"
    SHA3_384 = "sha3-384"
    SHA3_512 = "sha3-512"
    TLSH = "tlsh"
    CDHASH = "cdhash"
    FILENAME_AUTHENTIHASH = "filename|authentihash"
    FILENAME_VHASH = "filename|vhash"
    FILENAME_SSDEEP = "filename|ssdeep"
    FILENAME_IMPHASH = "filename|imphash"
    FILENAME_IMPFUZZY = "filename|impfuzzy"
    FILENAME_PEHASH = "filename|pehash"
    ILENAME_SHA224 = "ilename|sha224"
    FILENAME_SHA384 = "filename|sha384"
    FILENAME_SHA512 = "filename|sha512"
    FILENAME_SHA512_224 = "filename|sha512/224"
    FILENAME_SHA512_256 = "filename|sha512/256"
    FILENAME_SHA3_224 = "filename|sha3-224"
    FILENAME_SHA3_256 = "filename|sha3-256"
    FILENAME_SHA3_384 = "filename|sha3-384"
    FILENAME_SHA3_512 = "filename|sha3-512"
    FILENAME_TLSH = "filename|tlsh"
    WINDOWS_SCHEDULED_TASK = "windows-scheduled-task"
    WINDOWS_SERVICE_NAME = "windows-service-name"
    WINDOWS_SERVICE_DISPLAYNAME = "windows-service-displayname"
    WHOIS_REGISTRANT_EMAIL = "whois-registrant-email"
    WHOIS_REGISTRANT_PHONE = "whois-registrant-phone"
    WHOIS_REGISTRANT_NAME = "whois-registrant-name"
    WHOIS_REGISTRANT_ORG = "whois-registrant-org"
    WHOIS_REGISTRAR = "whois-registrar"
    WHOIS_CREATION_DATE = "whois-creation-date"
    X509_FINGERPRINT_SHA1 = "x509-fingerprint-sha1"
    X509_FINGERPRINT_MD5 = "x509-fingerprint-md5"
    X509_FINGERPRINT_SHA256 = "x509-fingerprint-sha256"
    DNS_SOA_EMAIL = "dns-soa-email"
    SIZE_IN_BYTES = "size-in-bytes"
    COUNTER = "counter"
    DATETIME = "datetime"
    PORT = "port"
    IP_DST_PORT = "ip-dst|port"
    IP_SRC_PORT = "ip-src|port"
    HOSTNAME_PORT = "hostname|port"
    MAC_ADDRESS = "mac-address"
    MAC_EUI_64 = "mac-eui-64"
    EMAIL_DST_DISPLAY_NAME = "email-dst-display-name"
    EMAIL_SRC_DISPLAY_NAME = "email-src-display-name"
    EMAIL_HEADER = "email-header"
    EMAIL_REPLY_TO = "email-reply-to"
    EMAIL_X_MAILER = "email-x-mailer"
    EMAIL_MIME_BOUNDARY = "email-mime-boundary"
    EMAIL_THREAD_INDEX = "email-thread-index"
    EMAIL_MESSAGE_ID = "email-message-id"
    GITHUB_USERNAME = "github-username"
    GITHUB_REPOSITORY = "github-repository"
    GITHUB_ORGANISATION = "github-organisation"
    JABBER_ID = "jabber-id"
    TWITTER_ID = "twitter-id"
    DKIM = "dkim"
    DKIM_SIGNATURE = "dkim-signature"
    FIRST_NAME = "first-name"
    MIDDLE_NAME = "middle-name"
    LAST_NAME = "last-name"
    FULL_NAME = "full-name"
    DATE_OF_BIRTH = "date-of-birth"
    PLACE_OF_BIRTH = "place-of-birth"
    GENDER = "gender"
    PASSPORT_NUMBER = "passport-number"
    PASSPORT_COUNTRY = "passport-country"
    PASSPORT_EXPIRATION = "passport-expiration"
    REDRESS_NUMBER = "redress-number"
    NATIONALITY = "nationality"
    VISA_NUMBER = "visa-number"
    ISSUE_DATE_OF_THE_VISA = "issue-date-of-the-visa"
    PRIMARY_RESIDENCE = "primary-residence"
    COUNTRY_OF_RESIDENCE = "country-of-residence"
    SPECIAL_SERVICE_REQUEST = "special-service-request"
    FREQUENT_FLYER_NUMBER = "frequent-flyer-number"
    TRAVEL_DETAILS = "travel-details"
    PAYMENT_DETAILS = "payment-details"
    PLACE_PORT_OF_ORIGINAL_EMBARKATION = "place-port-of-original-embarkation"
    PLACE_PORT_OF_CLEARANCE = "place-port-of-clearance"
    PLACE_PORT_OF_ONWARD_FOREIGN_DESTINATION = "place-port-of-onward-foreign-destination"
    PASSENGER_NAME_RECORD_LOCATOR_NUMBER = "passenger-name-record-locator-number"
    MOBILE_APPLICATION_ID = "mobile-application-id"
    AZURE_APPLICATION_ID = "azure-application-id"
    CHROME_EXTENSION_ID = "chrome-extension-id"
    CORTEX = "cortex"
    BOOLEAN = "boolean"
    ANONYMISED = "anonymised"


class CreateWarninglistBody(BaseModel):
    name: str = Field(min_length=1, max_length=255)
    type: WarninglistListType
    description: str = Field(min_length=1, max_length=65535)
    enabled: bool
    default: bool
    category: WarninglistCategory
    valid_attributes: list[ValidAttribute]
    values: str = Field(min_length=1, max_length=65535)

    class Config:
        orm_mode = True

==> mmisp_lib-0.1.9.tar.gz: mmisp_lib-0.1.9/src/mmisp/api_schemas/warninglists/create_warninglist_body.py <==
from enum import StrEnum

from pydantic import BaseModel, Field


class WarninglistListType(StrEnum):
    CIDR = "cidr"
    HOSTNAME = "hostname"
    STRING = "string"
    SUBSTRING = "substring"
    REGEX = "regex"


class WarninglistCategory(StrEnum):
    FALSE_POSITIVE = "False positive"
    KNOWN_IDENTIFIER = "Known identifier"


# todo: use something from the mmisp.lib.attributes
class ValidAttribute(StrEnum):
    MD5 = "md5"
    SHA12SHA256 = "sha12sha256"
    FILENAME = "filename"
    PDB = "pdb"
    FILENAME_MD5 = "filename|md5"
    FILENAME_SHA1 = "filename|sha1"
    FILENAME_SHA256 = "filename|sha256"
    IP_SRC = "ip-src"
    IP_DST = "ip-dst"
    HOSTNAME = "hostname"
    DOMAIN = "domain"
    DOMAIN_IP = "domain|ip"
    EMAIL = "email"
    EMAIL_SRC = "email-src"
    EPPN = "eppn"
    EMAIL_DST = "email-dst"
    EMAIL_SUBJECT = "email-subject"
    EMAIL_ATTACHMENT = "email-attachment"
    EMAIL_BODY = "email-body"
    FLOAT = "float"
    GIT_COMMIT_ID = "git-commit-id"
    URL = "url"
    HTTP_METHOD = "http-method"
    USER_AGENT = "user-agent"
    JA3_FINGERPRINT_MD5 = "ja3-fingerprint-md5"
    JARM_FINGERPRINT = "jarm-fingerprint"
    FAVICON_MMH3 = "favicon-mmh3"
    HASSH_MD5 = "hassh-md5"
    HASSHSERVER_MD5 = "hasshserver-md5"
    REGKEY = "regkey"
    REGKEY_VALUE = "regkey|value"
    AS = "AS"
    SNORT = "snort"
    BRO = "bro"
    ZEEK = "zeek"
    COMMUNITY_ID = "community-id"
    PATTERN_IN_FILE = "pattern-in-file"
    PATTERN_IN_TRAFFIC = "pattern-in-traffic"
    PATTERN_IN_MEMORY = "pattern-in-memory"
    FILENAME_PATTERN = "filename-pattern"
    PGP_PUBLIC_KEY = "pgp-public-key"
    PGP_PRIVATE_KEY = "pgp-private-key"
    SSH_FINGERPRINT = "ssh-fingerprint"
    YARA = "yara"
    STIX2_PATTERN = "stix2-pattern"
    SIGMA = "sigma"
    GENE = "gene"
    KUSTO_QUERY = "kusto-query"
    MIME_TYPE = "mime-type"
    IDENTITY_CARD_NUMBER = "identity-card-number"
    COOKIE = "cookie"
    VULNERABILITY = "vulnerability"
    CPE = "cpe"
    WEAKNESS = "weakness"
    ATTACHMENT = "attachment"
    MALWARE_SAMPLE = "malware-sample"
    LINK = "link"
    COMMENT = "comment"
    TEXT = "text"
    HEX = "hex"
    OTHER = "other"
    NAMED_PIPE = "named pipe"
    MUTEX = "mutex"
    PROCESS_STATE = "process-state"
    TARGET_USER = "target-user"
    TARGET_EMAIL = "target-email"
    TARGET_MACHINE = "target-machine"
    TARGET_ORG = "target-org"
    TARGET_LOCATION = "target-location"
    TARGET_EXTERNAL = "target-external"
    BTC = "btc"
    DASH = "dash"
    XMR = "xmr"
    IBAN = "iban"
    BIC = "bic"
    BANK_ACCOUNT_NR = "bank-account-nr"
    ABA_RTN = "aba-rtn"
    BIN = "bin"
    CC_NUMBER = "cc-number"
    PRTN = "prtn"
    PHONE_NUMBER = "phone-number"
    THREAT_ACTOR = "threat-actor"
    CAMPAIGN_NAME = "campaign-name"
    CAMPAIGN_ID = "campaign-id"
    MALWARE_TYPE = "malware-type"
    URI = "uri"
    AUTHENTIHASH = "authentihash"
    VHASH = "vhash"
    SSDEEP = "ssdeep"
    IMPHASH = "imphash"
    TELFHASH = "telfhash"
    PEHASH = "pehash"
    IMPFUZZY = "impfuzzy"
    SHA224 = "sha224"
    SHA384 = "sha384"
    SHA512 = "sha512"
    SHA512_224 = "sha512/224"
    SHA512_256 = "sha512/256"
    SHA3_224 = "sha3-224"
    SHA3_256 = "sha3-256"
    SHA3_384 = "sha3-384"
    SHA3_512 = "sha3-512"
    TLSH = "tlsh"
    CDHASH = "cdhash"
    FILENAME_AUTHENTIHASH = "filename|authentihash"
    FILENAME_VHASH = "filename|vhash"
    FILENAME_SSDEEP = "filename|ssdeep"
    FILENAME_IMPHASH = "filename|imphash"
    FILENAME_IMPFUZZY = "filename|impfuzzy"
    FILENAME_PEHASH = "filename|pehash"
    ILENAME_SHA224 = "ilename|sha224"
    FILENAME_SHA384 = "filename|sha384"
    FILENAME_SHA512 = "filename|sha512"
    FILENAME_SHA512_224 = "filename|sha512/224"
    FILENAME_SHA512_256 = "filename|sha512/256"
    FILENAME_SHA3_224 = "filename|sha3-224"
    FILENAME_SHA3_256 = "filename|sha3-256"
    FILENAME_SHA3_384 = "filename|sha3-384"
    FILENAME_SHA3_512 = "filename|sha3-512"
    FILENAME_TLSH = "filename|tlsh"
    WINDOWS_SCHEDULED_TASK = "windows-scheduled-task"
    WINDOWS_SERVICE_NAME = "windows-service-name"
    WINDOWS_SERVICE_DISPLAYNAME = "windows-service-displayname"
    WHOIS_REGISTRANT_EMAIL = "whois-registrant-email"
    WHOIS_REGISTRANT_PHONE = "whois-registrant-phone"
    WHOIS_REGISTRANT_NAME = "whois-registrant-name"
    WHOIS_REGISTRANT_ORG = "whois-registrant-org"
    WHOIS_REGISTRAR = "whois-registrar"
    WHOIS_CREATION_DATE = "whois-creation-date"
    X509_FINGERPRINT_SHA1 = "x509-fingerprint-sha1"
    X509_FINGERPRINT_MD5 = "x509-fingerprint-md5"
    X509_FINGERPRINT_SHA256 = "x509-fingerprint-sha256"
    DNS_SOA_EMAIL = "dns-soa-email"
    SIZE_IN_BYTES = "size-in-bytes"
    COUNTER = "counter"
    DATETIME = "datetime"
    PORT = "port"
    IP_DST_PORT = "ip-dst|port"
    IP_SRC_PORT = "ip-src|port"
    HOSTNAME_PORT = "hostname|port"
    MAC_ADDRESS = "mac-address"
    MAC_EUI_64 = "mac-eui-64"
    EMAIL_DST_DISPLAY_NAME = "email-dst-display-name"
    EMAIL_SRC_DISPLAY_NAME = "email-src-display-name"
    EMAIL_HEADER = "email-header"
    EMAIL_REPLY_TO = "email-reply-to"
    EMAIL_X_MAILER = "email-x-mailer"
    EMAIL_MIME_BOUNDARY = "email-mime-boundary"
    EMAIL_THREAD_INDEX = "email-thread-index"
    EMAIL_MESSAGE_ID = "email-message-id"
    GITHUB_USERNAME = "github-username"
    GITHUB_REPOSITORY = "github-repository"
    GITHUB_ORGANISATION = "github-organisation"
    JABBER_ID = "jabber-id"
    TWITTER_ID = "twitter-id"
    DKIM = "dkim"
    DKIM_SIGNATURE = "dkim-signature"
    FIRST_NAME = "first-name"
    MIDDLE_NAME = "middle-name"
    LAST_NAME = "last-name"
    FULL_NAME = "full-name"
    DATE_OF_BIRTH = "date-of-birth"
    PLACE_OF_BIRTH = "place-of-birth"
    GENDER = "gender"
    PASSPORT_NUMBER = "passport-number"
    PASSPORT_COUNTRY = "passport-country"
    PASSPORT_EXPIRATION = "passport-expiration"
    REDRESS_NUMBER = "redress-number"
    NATIONALITY = "nationality"
    VISA_NUMBER = "visa-number"
    ISSUE_DATE_OF_THE_VISA = "issue-date-of-the-visa"
    PRIMARY_RESIDENCE = "primary-residence"
    COUNTRY_OF_RESIDENCE = "country-of-residence"
    SPECIAL_SERVICE_REQUEST = "special-service-request"
    FREQUENT_FLYER_NUMBER = "frequent-flyer-number"
    TRAVEL_DETAILS = "travel-details"
    PAYMENT_DETAILS = "payment-details"
    PLACE_PORT_OF_ORIGINAL_EMBARKATION = "place-port-of-original-embarkation"
    PLACE_PORT_OF_CLEARANCE = "place-port-of-clearance"
    PLACE_PORT_OF_ONWARD_FOREIGN_DESTINATION = "place-port-of-onward-foreign-destination"
    PASSENGER_NAME_RECORD_LOCATOR_NUMBER = "passenger-name-record-locator-number"
    MOBILE_APPLICATION_ID = "mobile-application-id"
    AZURE_APPLICATION_ID = "azure-application-id"
    CHROME_EXTENSION_ID = "chrome-extension-id"
    CORTEX = "cortex"
    BOOLEAN = "boolean"
    ANONYMISED = "anonymised"


class CreateWarninglistBody(BaseModel):
    name: str = Field(min_length=1, max_length=255)
    type: WarninglistListType
    description: str = Field(min_length=1, max_length=65535)
    enabled: bool
    default: bool
    category: WarninglistCategory
    valid_attributes: list[ValidAttribute]
    values: str = Field(min_length=1, max_length=65535)

    class Config:
        orm_mode = True
